/*
 * Copyright 2012 Hasan Hosgel
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package de.alosdev.android.customerschoice.logger;

import android.util.Log;
import de.alosdev.android.customerschoice.CustomersChoice;


/**
 * This interface allows to use pluggable {@link Logger}. The default implementation is the {@link NoLogger}.
 * If you want to use the default android {@link Log} you can configure the {@link AndroidLogger} as the used
 * {@link Logger} in the {@link CustomersChoice#addLoggers(Logger...)}. It contains the main log methods of the Android
 * {@link Log}. The main difference it the var args list, which can also contain a {@link Throwable}.
 * @author Hasan Hosgel
 *
 */
public interface Logger {
  void d(String tag, Object... args);

  void i(String tag, Object... args);

  void w(String tag, Object... args);

  void e(String tag, Object... args);

}
